# std lib
import math
from random import random, randint

# pyglet
import pyglet
from pyglet.gl import *
from pyglet.window.key import *

# cocos
import cocos
from cocos.director import director
from cocos.sprite import Sprite
from cocos import euclid
from cocos.actions.interval_actions import MoveBy, MoveTo, ScaleBy, JumpBy, RotateBy, Delay, Accelerate, AccelDeccel
from cocos.actions.instant_actions import Hide, Show, Place, CallFunc
from cocos.actions.base_actions import Reverse, Repeat
from cocos.text import Label

import soundex
#import gameover

def log(txt):
    print txt

fox_killed = False

class BackgroundLayer(cocos.layer.Layer):
    def __init__(self):
        super(BackgroundLayer, self).__init__()
        grass = Sprite('grass_1_4.png', position=(1024/2, 768/2))
        self.add(grass, z=0)

def is_inside(sprite, x_, y_):
    x = sprite.x
    y = sprite.y
    w2 = sprite.width / 2
    h2 = sprite.height / 2
    #log("a %d %d is in %d %d - %d %d" % (x_, y_, x, y, w2, h2))
    if x_ > x - w2 and x_ < x + w2 and y_ > y - h2 and y_ < y + h2:
        return True
    return False

class CtrlLayer(cocos.layer.Layer):
    is_event_handler = True
    def __init__(self):
        super(CtrlLayer, self).__init__()
        night = Sprite('night.png', position=(1024/2, 768/2), opacity=200)
        self.add(night, z=100)

        self.fox = Sprite('fox_4.png', position=(200, 200), scale=0.7)
        self.add(self.fox, z=50)

        self.barrel = Sprite('barrel.png', position=(600, 70), scale=0.7)
        self.add(self.barrel, z=60)
        self.barrel_dir = -1

        self._swing_barrel()
        
        self._move_fox()

        #self.schedule_interval(self._update, 5)

    def _move_fox(self):
        x = random()*1024
        y = 160 + random()*(768-160-100)
        d = math.sqrt(x*x + y*y)
        t = d/(2*1024)
                    
        a = Accelerate(MoveTo((x, y), t), 2)
        a = a + Delay(0.25) + CallFunc(self._move_fox)
        self.fox.do(a)

    def _swing_barrel(self):
        dy = int(random() * 40 - 20)
        m = MoveBy((self.barrel_dir*40, dy), 1) + MoveBy((self.barrel_dir*40, -dy), 1)
        a = AccelDeccel(m)
        a = a + CallFunc(self._swing_barrel)
        self.barrel_dir = -self.barrel_dir
        self.barrel.do(a)
        

    def on_mouse_press (self, x, y, buttons, modifiers):
        global fox_killed
        print x, y
        if random() < 0.2:
            soundex.play("burst.wav")
        else:
            soundex.play("shot.wav")
        if is_inside(self.fox, x, y):
            log("bingo")
            fox_killed = True
            director.pop()

    def _update(self, dt):
        pass

def get_scene():
    s = cocos.scene.Scene()
    s.add(BackgroundLayer(), z=0)
    s.add(CtrlLayer(), z=1)
    return s
